Documentation
¶
Overview ¶
Package xfs implements a read/write XFS filesystem driver (v4 and v5). All metadata is big-endian as required by the XFS specification. I/O is zero-copy via an io.SectionReader; writes land in a dirty-block cache that is flushed to the backing store on Unmount.
Index ¶
- type Volume
- func (v *Volume) Chmod(name string, mode fs.FileMode) error
- func (v *Volume) Chown(name string, uid, gid int) error
- func (v *Volume) Chtimes(name string, atime, mtime time.Time) error
- func (v *Volume) Create(name string) (*volfs.File, error)
- func (v *Volume) Link(oldname, newname string) error
- func (v *Volume) Lstat(name string) (fs.FileInfo, error)
- func (v *Volume) Mkdir(name string, perm fs.FileMode) error
- func (v *Volume) MkdirAll(p string, perm fs.FileMode) error
- func (v *Volume) Open(name string) (fs.File, error)
- func (v *Volume) OpenFile(name string, flag int, perm fs.FileMode) (*volfs.File, error)
- func (v *Volume) ReadDir(name string) ([]fs.DirEntry, error)
- func (v *Volume) ReadFile(name string) ([]byte, error)
- func (v *Volume) Readlink(name string) (string, error)
- func (v *Volume) Remove(name string) error
- func (v *Volume) RemoveAll(p string) error
- func (v *Volume) Rename(oldpath, newpath string) error
- func (v *Volume) Stat(name string) (fs.FileInfo, error)
- func (v *Volume) StatFS() (volfs.VolumeInfo, error)
- func (v *Volume) Symlink(oldname, newname string) error
- func (v *Volume) Type() fstype.Type
- func (v *Volume) Unmount() error
- func (v *Volume) WriteFile(name string, data []byte, perm fs.FileMode) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Volume ¶
type Volume struct {
// contains filtered or unexported fields
}
Volume implements fs.Volume for an XFS partition.
func Open ¶
Open parses the XFS superblock and AG headers from the given partition bounds and returns a ready-to-use Volume.
Click to show internal directories.
Click to hide internal directories.